@@ -8,21 +8,20 @@ NULL
 #' Generates Univariate Generalized Poisson Variates
 #'
 #' \code{GenUniGpois} generates univariate random variables from the generalized Poisson
-#' distribution using one of the five methods including Inversion, Branching, Normal-Approximation, Build-Up, Chop-Down.
+#' distribution using one of the five methods including Inversion, Branching, Normal-Approximation, Build-Up, and Chop-Down.
 #'
 #' @param theta the rate parameter in the generalized Poisson distribution. It has to be a positive number.
 #' @param lambda the dispersion parameter in the generalized Poisson distribution.
-#'  It has to be < 1. For lambda < 0, lambda must be greater than or equal to -theta/4.
+#'  It has to be less than 1. For lambda < 0, lambda must be greater than or equal to -theta/4.
 #' @param n number of data points that is to be generated.
-#' @param details index to indicate whether or not to print out the estimates of parameters.
-#'  The default is set as TRUE.
-#' @param method index to specify one of the five methods: "Inversion", "Branching", "Normal-Approximation", "Build-Up" and "Chop-Down".
+#' @param details index to indicate whether to print out the estimates of parameters. Default is set to TRUE.
+#' @param method index to specify one of the five methods: "Inversion", "Branching", "Normal-Approximation", "Build-Up" or "Chop-Down".
 #' @details
 #'  All five methods come from Demirtas (2017).
-#'  When lambda equals 0, it is the ordinary Poisson distribution, so there is no need to specify the method.
+#'  When lambda equals to 0, it is the ordinary Poisson distribution, so there is no need to specify the method.
 #'  "Branching" only works when lambda is positive.
-#'  When theta is less than 10, a "Normal-Approximation" may not be reliable.
-#' @return a list that includes generated data, specified and empirical values of theta and lambda.
+#'  When theta is less than 10, the "Normal-Approximation" may not be reliable.
+#' @return a list that includes generated data, specified and empirical values of theta and lambda, and the specified method.
 #' @examples
 #'  GenUniGpois(2, 0.9, 100, method = "Branching")
 #'  GenUniGpois(5, -0.4, 100, method = "Inversion")
@@ -34,19 +33,19 @@ NULL
 #'  Poisson variates. \emph{Communications in Statistics - Simulation and Computation},
 #'   \bold{46(1)}, 489-499.
 #' @export
-GenUniGpois <- function(theta, lambda, n, details = TRUE, method){
+GenUniGpois <- function(theta, lambda, n, details = TRUE, method) {
   # Check if parameters are valid
   tol <- .Machine$double.eps^0.5
   if (n <= 0 | abs(n - round(n)) > tol) {
     stop("n must be a positive integer.")
   }
   if(n == 1) stop("Parameter estimates are exactly the same as input of parameters in the case when n = 1!")
-  if(theta <= 0) stop("Theta has to be greater than 0!")
-  if(lambda >= 1) stop("Lambda has to be less than 1!")
-  if (lambda < 0 & lambda < (-theta) / 4) stop(paste("For lambda < 0, lambda must be >= -theta/4 = ", (-theta)/4, "!", sep = ""))
+  if(theta <= 0) stop("theta has to be greater than 0!")
+  if(lambda >= 1) stop("lambda has to be less than 1!")
+  if (lambda < 0 & lambda < (-theta) / 4) stop(paste("For lambda < 0, lambda must be greater than or equal to -theta/4 which is ", (-theta)/4, "!", sep = ""))
   myset = numeric(n)
   if (lambda == 0) { # 1. rpois function
-    myset = rpois(n,theta)
+    myset = rpois(n, theta)
     if (n != 1) {
       model = vglm(myset ~ 1, family = genpoisson(zero = 1))
       coef = Coef(model, matrix = TRUE)
@@ -62,7 +61,7 @@ GenUniGpois <- function(theta, lambda, n, details = TRUE, method){
       u = runif(1)
       while (u > mys){
         x = x + 1
-        myc = theta - lambda + lambda*x
+        myc = theta - lambda + lambda * x
         myp = w * myc * (1 + lambda/myc)^(x-1) * myp * x^(-1)
         mys = mys + myp
       }
@@ -119,7 +118,7 @@ GenUniGpois <- function(theta, lambda, n, details = TRUE, method){
       s = px
       while (u > s) {
         x = x + 1
-        px = theta * (theta + lambda * x)^(x - 1)*exp(-theta - lambda * x) / factorial(x)
+        px = theta * (theta + lambda * x)^(x - 1) * exp(-theta - lambda * x) / factorial(x)
         s = s + px
       }
       myset[i] = x
@@ -159,7 +158,8 @@ GenUniGpois <- function(theta, lambda, n, details = TRUE, method){
                          specified.theta = theta,
                          empirical.theta = as.numeric(emp.theta),
                          specified.lambda = lambda,
-                         empirical.lambda = as.numeric(emp.lambda))))
+                         empirical.lambda = as.numeric(emp.lambda),
+                         method = method)))
 }
 
 
