@@ -1,5 +1,4 @@
 #' @include ComputeCorrGpois.R
-#' @include GenUniGpois.R
 #' @importFrom corpcor is.positive.definite
 NULL
 
@@ -13,12 +12,15 @@ NULL
 #' @param theta.vec rate parameters in the generalized Poisson distribution. It is assumed that the
 #'  length of the vector is at least two, and each value has to be a positive number.
 #' @param lambda.vec dispersion parameters in the generalized Poisson distribution. It is assumed that the length
-#'  of the vector is at least two. All lambda values have to be < 1. For lambda < 0, lambda must be >= -theta/4.
+#'  of the vector is at least two. All lambda values have to be less than 1. For lambda < 0, lambda must be greater than or equal to -theta/4.
+#' @param verbose logical variable that determines whether to display the traces. Default is set to TRUE.
 #' @return TRUE or FALSE.
 #' @examples
 #' \donttest{
-#'  ValidCorrGpois(matrix(c(1, 0.9, 0.9, 1), byrow = TRUE, nrow = 2), c(0.5, 0.5), c(0.1, 0.105))
-#'  ValidCorrGpois(matrix(c(1, 0.9, 0.9, 1), byrow = TRUE, nrow = 2), c(3, 2), c(-0.3, -0.2))}
+#'  ValidCorrGpois(matrix(c(1, 0.9, 0.9, 1), byrow = TRUE, nrow = 2), 
+#'                 c(0.5, 0.5), c(0.1, 0.105), verbose = TRUE)
+#'  ValidCorrGpois(matrix(c(1, 0.9, 0.9, 1), byrow = TRUE, nrow = 2), 
+#'                 c(3, 2), c(-0.3, -0.2), verbose = TRUE)}
 #' @references
 #'  Amatya, A. and Demirtas, H. (2017). PoisNor: An R package for generation of multivariate data with
 #'  Poisson and normal marginals. \emph{Communications in Statistics - Simulation and Computation},
@@ -27,7 +29,7 @@ NULL
 #'  Demirtas, H. and Hedeker, D. (2011). A practical way for computing approximate lower and upper correlation bounds.
 #'  \emph{The American Statistician}, \bold{65(2)}, 104-109.
 #' @export
-ValidCorrGpois = function (corMat, theta.vec, lambda.vec) {
+ValidCorrGpois = function (corMat, theta.vec, lambda.vec, verbose = TRUE) {
   no.gpois = length(theta.vec)
   errorCount = 0
   if (ncol(corMat) != (no.gpois)) {
@@ -48,12 +50,15 @@ ValidCorrGpois = function (corMat, theta.vec, lambda.vec) {
   if (sum(diag(corMat) != 1) > 0) {
     stop("All diagonal elements of the correlation matrix must be 1! \n")
   }
-  maxcor = ComputeCorrGpois(theta.vec, lambda.vec)$max
-  mincor = ComputeCorrGpois(theta.vec, lambda.vec)$min
+  maxcor = ComputeCorrGpois(theta.vec, lambda.vec, verbose)$max
+  mincor = ComputeCorrGpois(theta.vec, lambda.vec, verbose)$min
   for (i in 1:nrow(corMat)) {
     for (j in 1:i) {
-      if (errorCount == 0)
+      if (errorCount == 0) {
+        if (verbose == TRUE) {
         cat(".")
+        }
+      }
       if (i != j) {
         if (corMat[i, j] > maxcor[i, j] | corMat[i, j] <  mincor[i, j]) {
           cat("\n corMat[", i, ",", j, "] must be between ", round(mincor[i,j], 3), " and ", round(maxcor[i,j], 3), "\n")
@@ -62,7 +67,9 @@ ValidCorrGpois = function (corMat, theta.vec, lambda.vec) {
       }
     }
   }
+  if (verbose == TRUE) {
   cat("\n")
+  }
   if (errorCount > 0) {
     stop("Range violation occurred in the target correlation matrix!\n")
   }
